@@ -18,14 +18,14 @@ sub lngbase {
 #push @msg, CGI::Bus::lngbase::CGI_Bus_tm_ru::lngbase;
  push @msg,
  (-lgn=>['',    '  ']
- ,-nap=>['',     '  ']
+ ,-nap=>['',     ' ']
  ,-nup=>['',     ' ']
- ,-nth=>['',    ' ']
+ ,-nth=>['',    '  -']
  ,-bck=>['',    '   ']
- ,-lst=>['',     '    ']
+ ,-lst=>['',     '     ()']
  ,-lsr=>['',     '  ']
- ,-qry=>['',  '  ']
- ,-crt=>['',  '  ,      ']
+ ,-qry=>['',  '  () ']
+ ,-crt=>['',  '  ,   \'\'    ']
  ,-sel=>['',  '()    ,  ']
  ,-edt=>['',   '  /  ']
  ,-frm=>['',     '   ,  ']
