@@ -33,7 +33,7 @@ sub lngbase {
  ,'FramesetURLs'=>[' URL',   'URL \'\'  ,    ,  HTML \'\' ;      ']
  ,'FramesetRows'=>[' ',  '  ,   %,  ']
  ,'FramesetCols'=>[' ', '  ,   %,  ']
- ,'FavoriteURLs'=>[' URL',   'URL     ,    ,   \'|URL\'  \'|_blank|URL\'    HTML']
+ ,'FavoriteURLs'=>[' URL',   'URL     ,    ,   \'|URL\', \'|_blank|URL\', \'|_parent|URL\', \'|URL|_|URL\',  HTML']
  ,'PrimaryRole' =>[' ',   '  ']
  ,'Read'        =>['',      ' ']
  ,'Save'        =>['',       ' ']
